@@ -222,7 +222,7 @@ if ($do==1) {
       "FullAutoAPI/root/static/images",'__display__');
    ($stdout,$stderr)=$handle->cmd("cp -v $builddir/$ls_tmp[0]/api/*tt ".
       "FullAutoAPI/root",'__display__');
-   ($stdout,$stderr)=$handle->cmd("cp -v $lddir/$ls_tmp[0]/demo/FA.ico ".
+   ($stdout,$stderr)=$handle->cmd("cp -v $builddir/$ls_tmp[0]/demo/FA.ico ".
       "FullAutoAPI/root/favicon.ico",'__display__');
    ($stdout,$stderr)=$handle->cwd("FullAutoAPI/deps");
    ($stdout,$stderr)=$handle->cmd(
